import React, { useContext, useEffect } from 'react'
import PropTypes from 'prop-types'
import { GraphContext } from '../utils/index.js'
import * as d3 from '../utils/d3.js'


const Zoomable = ({
	scale = 1,
	scaleExtent = [0.5, 1],
	children = null,
	onZoom = group => {
		group.attr('transform', d3.event.transform)
	}
}) => {
	const { svg, zoomGroup } = useContext(GraphContext)
	const zoom = d3.zoom()

	useEffect(() => {
		const container = d3.select(svg.current)
		const group = d3.select(zoomGroup.current)

		container.style('cursor', 'move')
		zoom.on('zoom', () => onZoom(group))
		zoom.scaleExtent(scaleExtent)
		zoom.filter(() => !d3.event.shiftKey)
		zoom(container)
		zoom.transform(container, d3.zoomIdentity.scale(scale))
	}, [ scale ])
	
	return children
}

Zoomable.propTypes = {
	children: PropTypes.node,
	onZoom: PropTypes.func
}

export default Zoomable